import { IDictionary } from "@globalpayments/js/types/internal/lib/util";
import { IframeField } from "@globalpayments/js/types/ui/iframe-field";
import UIForm from "@globalpayments/js/types/ui/form";
export declare type CallbackFn = (e?: object) => any;
export declare type EventOnCallback = (eventOrTarget: string, callbackOrEvent: CallbackFn, callback?: CallbackFn) => any;
export declare class SecurePaymentElement extends HTMLElement {
    /**
     * RegEx for finding all valid secure payment element names
     */
    static FIND_ALL_REGEX: RegExp;
    /**
     * Attribute name for custom iframe styles
     */
    static ATTRIBUTE_NAME_STYLES: string;
    protected on: EventOnCallback;
    /**
     * Sets the underlying hosted field.
     *
     * Exposes functionality from the hosted field object to the custom
     * element's JavaScript interface.
     *
     * @param value
     */
    set field(value: IframeField);
    /**
     * Gets the underlying hosted field.
     */
    get field(): IframeField;
    /**
     * Gets the custom element's pre-defined tag name.
     */
    get tagName(): string;
    /**
     * Gets the hosted field type.
     *
     * Current options are:
     *
     * - `card-number`
     * - `card-expiration`
     * - `card-cvv`
     * - `submit`
     */
    get type(): string;
    /**
     * @returns List of event types supported on the element.
     */
    getTargetEvents(): string[];
    /**
     * Gets the element's attributes as an object, replacing kebab cased attribute
     * names with their camel cased equivalents.
     */
    getAttributes(): IDictionary;
    /**
     * Gets hosted fields styles if they have been set on the custom element.
     *
     * @returns An empty object if no styles have been set.
     */
    getStyles(): {};
    /**
     * Determines if hosted fields styles have been set on the custom element.
     */
    hasStyles(): boolean;
    /**
     * Sets up event listeners to forward events from the Global Payments
     * JavaScript library to be dispatched as `CustomEvent`s from this
     * element.
     *
     * @param source
     */
    setupEventListeners(source: IframeField | UIForm): void;
    /**
     * Converts kebab case (`kebab-case`) to camel case (`camelCase`).
     *
     * @param name
     */
    protected kebabCaseToCamelCase(name: string): string;
    /**
     * Replaces generic CSS selectors (e.g. `input`) with alternatives for the specific
     * input field.
     *
     * When configuring all hosted fields, all CSS is compiled together and sent to each
     * field that is constructed. Scoping CSS selectors prevents unintended side effects.
     *
     * @param styles
     */
    protected scopeInputSelectors(styles: IDictionary): IDictionary;
    /**
     * Upgrades a property when the custom element is defined.
     *
     * @param prop Property name
     */
    protected upgradeProperty(prop: string): void;
}
